@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2017-2021 Greenbone Networks GmbH
+# Copyright (C) 2017-2021 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -38,7 +38,7 @@ __version__ = "21.7.0"
 logger = logging.getLogger(__name__)
 
 HELP_TEXT = f"""
-    Check-GMP Nagios Command Plugin {__version__} (C) 2017-2021 Greenbone Networks GmbH
+    Check-GMP Nagios Command Plugin {__version__} (C) 2017-2021 Greenbone AG
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -185,7 +185,7 @@ class InstanceManager:
 
         # Retrieve the scan_end value
         self.cursor.execute(
-            "SELECT scan_end, params_used FROM Report WHERE" " host=?",
+            "SELECT scan_end, params_used FROM Report WHERE host=?",
             (self.host,),
         )
         db_entry = self.cursor.fetchone()
@@ -202,7 +202,7 @@ class InstanceManager:
             new = parse_date(last_scan_end)
 
             logger.debug(
-                "Old time (from db): %s\n" "New time (from rp): %s", old, new
+                "Old time (from db): %s\nNew time (from rp): %s", old, new
             )
 
             if new <= old and params_used == db_entry[1]:
@@ -506,7 +506,6 @@ class InstanceManager:
             number_instances < MAX_RUNNING_INSTANCES
             and number_pending_instances > 0
         ):
-
             pending_entries = self.get_oldest_pending_entries(
                 MAX_RUNNING_INSTANCES - number_instances
             )
