@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2017-2021 Greenbone Networks GmbH
+# Copyright (C) 2017-2021 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -91,7 +91,7 @@ def execute_send_delta_emails(sc: sched.scheduler, **kwargs: dict) -> None:
             continue
 
         if reports[0].xpath(
-            "report/user_tags/tag/" 'name[text()="delta_alert_sent"]'
+            'report/user_tags/tag/name[text()="delta_alert_sent"]'
         ):
             print("  Delta report for latest finished report already sent")
             continue
